function crm00050000_Associacoes_Revenda_Controller(General, CRM_Utilities, templateManager, restEngine, ScreenService, Messages, metaDataFactory) {

    /**
     * Função para salvar um operador
     * na revenda em caso.
     * 
     * @param {object(widget)} widget ativa onde
     * está será cadastrado um operador para a 
     * revenda.
    */
    this.saveResaleOperator = function(widget){
        
        var currentRow = widget.currentRow;
        
        this.setColumnToReturnInCurrentRow(currentRow, "NROPERREVENDA");
        
        General.widgetSave(widget).then(function(response){
            
            var resaleOperatorCode = response.dataset.columnsToReturn.NROPERREVENDA;
            
            this.setResaleOperatorCode(currentRow, resaleOperatorCode);
                
        }.bind(this));
            
    };
    
    /**
     * Função para setar a coluna a ser retornada
     * na resposta do 'save'.
     * 
     * @param {object} currentRow currentRow que receberá
     * a propriedade com o nome da coluna a ser retornada.
     * 
     * @param {string} columnName nome da coluna a ser
     * retornada.
    */
    this.setColumnToReturnInCurrentRow = function(currentRow, columnName){
    
        currentRow.__columns_to_return = [columnName];

    };
    
    /**
     * Função para atribuir a coluna retornada da requisição
     * 'SAVE' na currentRow do operador retornado.
     * 
     * @param {object} currentRow currentRow que irá 
     * receber o número do operador.
     * 
     * @param {String} resaleOperatorCode
     * código do operador que será inserido
     * na currentRow.
    */
    this.setResaleOperatorCode = function(currentRow, resaleOperatorCode){
        
        currentRow.NROPERREVENDA = resaleOperatorCode;
        
    };
    
    /**
     * Função para setar o valor do filtro
     * de NRORG da field 'NMOPERADOR'.
     * 
     * @param {object(widget)} widget widget
     * ativa onde está localizado a field 'NMOPERADOR'.
    */
    
    this.setNRREVENDA = function(widget){
        
        var pegaNRREVENDA = templateManager.container.getWidget('WDGT_REVENDA');
        var valorNRRVEVENDA = pegaNRREVENDA.currentRow.NRREVENDA;
      
        
        var montadasourcefilter = {name: "NRREVENDA",
                                   operator: "=",
                                   value: valorNRRVEVENDA};
        
        
        widget.dataSourceFilter[1] = montadasourcefilter;
        
  
        widget.reload();
    };
    
    this.setFilterOperatorField = function(widget){
        
        var parentWidget = widget.parent.parent;
        var client       = parentWidget.currentRow.CDCLIENTE;
        var insertFilter = true;
        
        var operatorField = widget.getField("NMOPERADOR");
        var operatorFilter = operatorField.dataSourceFilter;
        
        var nrorgFilterIndex = CRM_Utilities.getFilterPosition(operatorFilter, "P_NRORG");
        var nrRevendaFilterIndex = CRM_Utilities.getFilterPosition(operatorFilter, "P_NRREVENDA");
        
        if(!Util.isEmptyOrBlank(client)){
            operatorFilter.forEach(function(filter){
               if(filter.name === "CDCLIENTE"){
                   filter.value = client;
                   insertFilter = false;
                }
            });
            if(insertFilter){
                var clientFilter = {name:'CDCLIENTE', operator:'=', value:client};
                operatorFilter.push(clientFilter);
            }
        }else{
            operatorFilter.forEach(function(filter, index, operatorFilter){
               if(filter.name === "CDCLIENTE"){
                   operatorFilter.splice(index, 1);
                }
            });   
        }
        
        operatorFilter[nrorgFilterIndex].value = templateManager.LOGGEDOPERATOR.NRORG;
        operatorFilter[nrRevendaFilterIndex].value = parentWidget.currentRow.NRREVENDA;
        
        operatorField.reload();
            
    };
    
    /**
     * Função para salvar um prospect na revenda
     * em caso.
     * 
     * @param {object(widget)} widget widget ativa
     * onde está sendo salvo um novo prospect.
    */
    this.saveResaleProspect = function(widget){
        
        var currentRow = widget.currentRow;
        
        this.setColumnToReturnInCurrentRow(currentRow, "NRPROSPREVENDA");
        
        General.widgetSave(widget).then(function(response){
            
            var resaleProspectCode = response.dataset.columnsToReturn.NRPROSPREVENDA;
            
            this.setResaleProspectCode(currentRow ,resaleProspectCode);
            
        }.bind(this));
        
    };
    
    /**
     * Função para setar ,na currentRow, o 
     * código gerado para o novo prospect .
     * 
     * @param {object} currentRow currentRow que
     * receberá o código do prospect.
     * 
     * @param {String} resaleProspectCode code gerado
     * para o novo prospect cadastrado.
    */
    this.setResaleProspectCode = function(currentRow, resaleProspectCode){
        
        currentRow.NRPROSPREVENDA = resaleProspectCode;
        
    };
    
    /**
     * Função para setar os valores aos filtros
     * na field de prospect para vincular ao 
     * parâmeterbag.
     * 
     * @param {object(widget)} widget widget ativa
     * onde está sendo feito o cadastro do prospect
     * e onde se localiza a field de prospect.
    */
    this.setFilterProspectField = function(widget){
        
        var parentWidget = widget.parent.parent;
        
        var prospectField = widget.getField('NMRAZSOCPROS');
        var prospectFieldFilter = prospectField.dataSourceFilter;
        
        var nrorgFilterIndex = CRM_Utilities.getFilterPosition(prospectFieldFilter, "P_NRORG");
        var nrRevendaFilterIndex = CRM_Utilities.getFilterPosition(prospectFieldFilter, "P_NRREVENDA");
        
        prospectFieldFilter[nrorgFilterIndex].value = templateManager.LOGGEDOPERATOR.NRORG;
        prospectFieldFilter[nrRevendaFilterIndex].value = parentWidget.currentRow.NRREVENDA;
        
        prospectField.reload();
        
    };
    
    /**
     * Função para salvar um cliente na 
     * revenda em caso.
     * 
     * @param {object(widget)} widget widget ativa
     * onde está sendo feito o cadastro do novo cliente.
    */
    this.saveResaleClient = function(widget){
        
        var currentRow = widget.currentRow;
        
        this.setColumnToReturnInCurrentRow(currentRow, "NRCLIEREVENDA");
        
        General.widgetSave(widget).then(function(response){
            
            var resaleClientCode = response.dataset.columnsToReturn.NRCLIEREVENDA;
            
            this.setResaleClientCode(currentRow ,resaleClientCode);
            
        }.bind(this));
        
    };
    
    /**
     * Função para setar , na currentRow, o 
     * código gerado para o novo cliente.
     * 
     * @param {object} currentRow currentRow que
     * receberá o código do cliente.
    */
    this.setResaleClientCode = function(currentRow, resaleClientCode){
        
        currentRow.NRCLIEREVENDA = resaleClientCode;
        
    };
    
    /**
     * Função para setar o valor dos filtros
     * na field de cliente.
     * 
     * @param {object(widget)} widget widget ativa
     * onde está sendo feito o cadastro do cliente
     * e onde se localiza a field de clientes.
    */
    this.setFilterClientField = function(widget){
        
        var parentWidget = widget.parent.parent;
        
        var clientField = widget.getField('NMRAZSOCCLIE');
        var clientFieldFilter = clientField.dataSourceFilter;
        
        var nrorgFilterIndex = CRM_Utilities.getFilterPosition(clientFieldFilter, "P_NRORG");
        var nrRevendaFilterIndex = CRM_Utilities.getFilterPosition(clientFieldFilter, "P_NRREVENDA");
        
        clientFieldFilter[nrorgFilterIndex].value = templateManager.LOGGEDOPERATOR.NRORG;
        clientFieldFilter[nrRevendaFilterIndex].value = parentWidget.currentRow.NRREVENDA;
        
        clientField.reload();
        
    };
    
    /**
     * Função para definir o filtro da widget
     * de oportundiade (filha da widget de prospect da revenda).
     * 
     * @param {object} widget de oportunidade.
    */
    this.setOpportunityFilterBySelectedProspect = function(widget){
        
        var parentWidget = widget.parent.parent;
        
        var opportunityWidgetFilter = widget.dataSourceFilter;
        var nrparcoportFilterIndex = CRM_Utilities.getFilterPosition(opportunityWidgetFilter, "NRPARCOPORT");
        
        opportunityWidgetFilter[nrparcoportFilterIndex].value = parentWidget.currentRow.NRPARCNEGOCIO;
        
        widget.reload();
        
    };
    
    this.updateProspect = function(widget){
      
        var currentRow = widget.currentRow;
        
        if(currentRow.NRPARCNEGOCIO){
            
            var paramsRestEngine = {
                "requestType": "Row",
                "row": currentRow
            };
                
            return restEngine.post('/crm_prosprevenda_prospect/updateProspect', paramsRestEngine,
                function(success){
                    
                   ScreenService.showMessage('Atualizado com sucesso');
                   ScreenService.closeSwipe();
                   General.changeWidgetAcessibility(widget.widgets, true);
                    
                }.bind(this),undefined,
                function(error){
                    
                    ScreenService.showMessage(Messages.CATCH_EXCEPTION_ERROR(error.data.error));
                    
                },undefined,undefined
            );
        
        }
          widget.reload();
        
    };
    
    /*cria as abas dos prospects da revenda*/
    
    this.setRevendaProspectWidgetOnActiveWidget = function(widget, position){
        widget.widgets = CRM_Utilities.setElementOnArrayDefinedPosition(this.factoryRevendaProspectElvolucaoWidget(widget), widget.widgets, position);
        widget.widgets = CRM_Utilities.setElementOnArrayDefinedPosition(this.factoryRevendaProspecTarefatWidget(widget), widget.widgets, position);
        widget.activate();
    };
    
    this.factoryRevendaProspectElvolucaoWidget = function(activeWidget){
        
        var revendaProspectEvolucao = {
            "id": "",
            "name": "WDGT_EVOLUCOES",
            "label": "Evoluções",
            "container": activeWidget.container,
            "parent": activeWidget,
            "template": "widget/master_detail/grid.html",
            "isVisible": true,
            "dataSource": {
                "name": "product#/evolcont_parcnegocio",
                "rest": true
            },
            "dataSourceFilter": [
                {
                    "name": "NRORG",
                    "operator": "=",
                    "value": "@getLocalVar('CRM_NRORGTRAB')@"
                },
                {
                    "name": "P_NRPARCNEGOCIO",
                    "operator": "=",
                    "value": "@General.getFieldValue('NRPARCNEGOCIO', 'WDGT_PROSPECT')@"
                }
            ],
            "events": [
                {
                    "name":"WidgetOnEnter",
                    "code":"args.owner.reload()"
                }
            ],
            "actions": [
                {
                    "id": "",
                    "name": "BACK_EDIT",
                    "label": "Cancelar",
                    "isVisible": true,
                    "showAsAction": "back_edit",
                    "events": [
                        {
                            "id": "",
                            "name": "ActionEvent",
                            "code": "General.widgetCancelForm(args.owner.widget); ger45000_Prospect_Controller.deleteTaskInfosInEvolutionWidget(args.owner.widget);"
                        }
                    ]
                },
                {
                    "id": "",
                    "name": "BACK_VIEW",
                    "label": "Voltar",
                    "isVisible": true,
                    "showAsAction": "back_view",
                    "events": [
                        {
                            "id": "",
                            "name": "ActionEvent",
                            "code": "General.widgetGoBackToList(args.owner.widget);"
                        }
                    ]
                },
                {
                    "id": "",
                    "name": "BACK_LIST",
                    "label": "Voltar",
                    "isVisible": true,
                    "showAsAction": "back_list",
                    "events": [
                        {
                            "id": "",
                            "name": "ActionEvent",
                            "code": "General.widgetGoBackToParent(args.owner.widget);"
                        }
                    ]
                }
            ],
            "fieldGroups": [
                {
                    "id": "",
                    "name": "AGENDAR_TAREFA",
                    "label": "Próxima Tarefa",
                    "collapsible": true,
                    "opened": true
                }
            ],
            "fields": [
                {
                    "id": "",
                    "name": "NRSEQEVOLCONT",
                    "label": "Código",
                    "class": "6",
                    "isVisible": false,
                    "readOnly": false,
                    "showOnList": false,
                    "template": "field/text-edit.html",
                    "descriptionOrder": 1
                },
                {
                    "id": "",
                    "name": "NRPARCNEGOCIO",
                    "label": "",
                    "template": "field/text-edit.html",
                    "showOnForm": false,
                    "showOnList": false,
                    "isVisible": false,
                    "readOnly": false,
                    "class": 6,
                    "events": []
                },
                {
                    "id": "",
                    "name": "DTHREVOLCONT",
                    "label": "Data da Evolução",
                    "template": "field/calendar.html",
                    "isVisible": true,
                    "showOnView": true,
                    "showOnForm": true,
                    "showOnList": true,
                    "readOnly": true,
                    "dateFormat": "DD/MM/YYYY HH:mm",
                    "class": 6,
                    "events": []
                },
                {
                    "id": "",
                    "name": "IDSENEVOCONT",
                    "label": "Sentido",
                    "template": "field/select-native.html",
                    "showOnForm": true,
                    "showOnView": true,
                    "showOnList": true,
                    "class": 6,
                    "valueField": "IDSENEVOLCONT",
                    "descriptionField": "NMSENEVOLCONT",
                    "defaultValue": "S",
                    "isVisible": true,
                    "events": [],
                    "validations": {
                        "required": true
                    },
                    "filterProperties": {
                        "validations": {}
                    },
                    "hideEmptyValue": true,
                    "dataSource": {
                        "data": [
                            {
                                "NMSENEVOLCONT": "Entrada",
                                "IDSENEVOLCONT": "E"
                            },
                            {
                                "NMSENEVOLCONT": "Saída",
                                "IDSENEVOLCONT": "S"
                            }
                        ]
                    }
                },
                {
                    "id": "",
                    "name": "NMOPERADOR",
                    "label": "Operador Responsável",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnForm": true,
                    "showOnList": true,
                    "readOnly": true,
                    "class": 12,
                    "itemsPerPage": 30,
                    "valueField": "CDOPEREVOL",
                    "descriptionField": "NMOPERADOR",
                    "dataSource": {
                        "name": "product#/operador",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "fields": [
                        {
                            "id": "",
                            "name": "NMOPERADOR",
                            "label": "Nome",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        }
                    ],
                    "dataSourceFilter": [],
                    "outData": {
                        "CDOPERADOR": "CDOPEREVOL",
                        "NMOPERADOR": "NMOPERADOR"
                    }
                },
                {
                    "id": "",
                    "name": "NMTIPOCONT",
                    "label": "Tipo de Contato",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnForm": true,
                    "showOnList": true,
                    "class": 6,
                    "valueField": "CDTIPOCONT",
                    "descriptionOrder": 1,
                    "descriptionField": "NMTIPOCONT",
                    "dataSource": {
                        "name": "product#/tipocont",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "dataSourceFilter": [],
                    "outData": {
                        "NMTIPOCONT": "NMTIPOCONT",
                        "CDTIPOCONT": "CDTIPOCONT"
                    },
                    "fields": [
                        {
                            "id": "",
                            "name": "NMTIPOCONT",
                            "label": "Tipo de contato",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        }
                    ],
                    "validations": {
                        "required": {}
                    }
                },
                {
                    "id": "",
                    "name": "NMMOTIEVOCON",
                    "label": "Motivo de Evolução",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnForm": true,
                    "showOnList": true,
                    "descriptionOrder": 2,
                    "class": 6,
                    "valueField": "CDMOTIEVOCON",
                    "descriptionField": "NMMOTIEVOCON",
                    "dataSource": {
                        "name": "product#/motievolcont_crm_perfiresult_crm_perfioper",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "dataSourceFilter": [
                        {
                            "name": "P_NRORG",
                            "operator": "=",
                            "value": ""
                        },
                        {
                            "name": "P_CDOPERADOR",
                            "operator": "=",
                            "value": ""
                        }
                    ],
                    "outData": {
                        "NMMOTIEVOCON": "NMMOTIEVOCON",
                        "CDMOTIEVOCON": "CDMOTIEVOCON"
                    },
                    "fields": [],
                    "events": [
                        {
                            "id": "",
                            "name": "FieldOnClick",
                            "code": "ger45000_Prospect_Controller.setContactReasonFilter(args.owner.field);"
                        }
                    ],
                    "validations": {
                        "required": {}
                    }
                },
                {
                    "id": "",
                    "name": "NMINTERLOCUTOR",
                    "label": "Interlocutor",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnForm": true,
                    "class": "6",
                    "valueField": "NRSEQINTERLOCUTOR",
                    "descriptionField": "NMINTERLOCUTOR",
                    "dataSource": {
                        "name": "product#/crud/crm_interlocutor",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "dataSourceFilter": [
                        {
                            "name": "NRPARCNEGOCIO",
                            "operator": "=",
                            "value": "@templateManager.container.getWidget('gridProspect').currentRow.NRPARCNEGOCIO@"
                        }
                    ],
                    "outData": {
                        "NMINTERLOCUTOR": "NMINTERLOCUTOR",
                        "NRSEQINTERLOCUTOR": "NRSEQINTERLOCUTOR"
                    },
                    "fields": [
                        {
                            "id": "",
                            "name": "NMINTERLOCUTOR",
                            "label": "Nome",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        },
                        {
                            "id": "",
                            "name": "NMCARGOINTERLOC",
                            "label": "Cargo",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        }
                    ],
                    "events": [
                        {
                            "id": "",
                            "name": "FieldOnClick",
                            "code": "args.owner.field.reload();"
                        }
                    ]
                },
                {
                    "id": "",
                    "name": "NMRESULTEVOL",
                    "label": "Resultado",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnForm": true,
                    "showOnList": true,
                    "class": 6,
                    "readOnly": true,
                    "valueField": "NRSEQRESULEVOL",
                    "descriptionField": "DESCRESULEVOL",
                    "dataSource": {
                        "name": "product#/crm_resultevol_crm_perfiresult_crm_perfioper",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "dataSourceFilter": [
                        {
                            "name": "P_NRORG",
                            "operator": "=",
                            "value": ""
                        },
                        {
                            "name": "P_CDOPERADOR",
                            "operator": "=",
                            "value": ""
                        },
                        {
                            "name": "IDRESULTEVOLUCAO",
                            "operator": "=",
                            "value": "SIM"
                        }
                    ],
                    "outData": {
                        "DESCRESULEVOL": "NMRESULTEVOL",
                        "NRSEQRESULEVOL": "NRSEQRESULEVOL",
                        "IDGERPROXATIV": "IDGERPROXATIV"
                    },
                    "validations": {
                        "required": {}
                    },
                    "fields": [
                        {
                            "id": "",
                            "name": "DESCRESULEVOL",
                            "label": "Resultado",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        }
                    ],
                    "events": [
                        {
                            "id": "",
                            "name": "FieldOnClick",
                            "code": "ger45000_Prospect_Controller.setResultFilter(args.owner.field);"
                        },
                        {
                            "id": "",
                            "name": "FieldOnChange",
                            "code": "ger45000_Prospect_Controller.checkNewTaskPermissionByEvolutionResult(args.owner.field.widget);"
                        }
                    ]
                },
                {
                    "id": "",
                    "name": "TXEVOLCONT",
                    "label": "Descrição",
                    "template": "field/textarea.html",
                    "isVisible": true,
                    "showOnForm": true,
                    "class": 12,
                    "textRows": 5,
                    "validations": {
                        "required": {}
                    }
                },
                {
                    "id": "",
                    "name": "DTPLANFILACONTA",
                    "label": "Data da Próxima Tarefa",
                    "template": "field/datetime.html",
                    "datetime-dateFormat": "dd/mm/yy",
                    "datetime-timeFormat": "HH:ii",
                    "isVisible": true,
                    "showOnList": false,
                    "showOnView": true,
                    "showOnForm": true,
                    "readOnly": true,
                    "class": 6,
                    "fieldGroup": "AGENDAR_TAREFA",
                    "events": []
                },
                {
                    "id": "",
                    "name": "NMOPERADORREAL",
                    "label": "Operador",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnList": false,
                    "showOnForm": true,
                    "showOnView": true,
                    "readOnly": true,
                    "fieldGroup": "AGENDAR_TAREFA",
                    "class": 6,
                    "valueField": "CDOPERADOR",
                    "descriptionField": "NMOPERADOR",
                    "dataSource": {
                        "name": "product#/crud/operador_crm_operrevenda",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "dataSourceFilter": [
                        {
                            "name": "IDTPOPERADOR",
                            "operator": "=",
                            "value": "@Util.isEmptyOrBlank(templateManager.LOGGEDOPERATOR.IDTPOPERADOR) ? 'E' : templateManager.LOGGEDOPERATOR.IDTPOPERADOR@"
                        }
                    ],
                    "fields": [
                        {
                            "id": "",
                            "name": "NMOPERADOR",
                            "label": "Nome",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        }
                    ],
                    "outData": {
                        "CDOPERADOR": "CDOPERREAL",
                        "NMOPERADOR": "NMOPERADORREAL"
                    },
                    "filterProperties": {
                        "showOnList": false,
                        "showOnForm": false,
                        "showOnView": false
                    }
                },
                {
                    "id": "",
                    "name": "DSFILACONTATO",
                    "label": "Assunto da Tarefa",
                    "template": "field/text-edit.html",
                    "isVisible": true,
                    "showOnList": false,
                    "showOnView": true,
                    "showOnForm": true,
                    "readOnly": true,
                    "fieldGroup": "AGENDAR_TAREFA",
                    "defaultValue": "Retornar contato",
                    "class": 12,
                    "events": []
                }
            ],
            "widgets": []
        };
        
        revendaProspectEvolucao = metaDataFactory.widgetFactory(revendaProspectEvolucao);
        CRM_Utilities.factoryWidgetActions(revendaProspectEvolucao);
        
        return revendaProspectEvolucao;
        
    };
    
    this.factoryRevendaProspecTarefatWidget = function(activeWidget){
        
        var revendaProspectTarefa = {
            "id": "",
            "name": "WDGT_TAREFASS",
            "label": "Agenda de Tarefas",
            "container": activeWidget.container,
            "parent": activeWidget,
            "template": "widget/master_detail/grid.html",
            "isVisible": true,
            "dataSource": {
                "name": "product#/filacontato_agendatarefas",
                "rest": true
            },
            "dataSourceFilter": [
                {
                    "name": "NRORG",
                    "operator": "=",
                    "value": "@getLocalVar('CRM_NRORGTRAB')@"
                },
                {
                    "name": "NRPARCNEGOCIO",
                    "operator": "=",
                    "value": "@templateManager.container.getWidget('WDGT_PROSPECT').currentRow.NRPARCNEGOCIO@"
                }
            ],
            "events": [
                {
                    "name":"WidgetOnEnter",
                    "code":"args.owner.reload()"
                }
            ],
            "actions": [
                {
                    "id": "",
                    "name": "BACK_EDIT",
                    "label": "Cancelar",
                    "isVisible": true,
                    "showAsAction": "back_edit",
                    "events": [
                        {
                            "id": "",
                            "name": "ActionEvent",
                            "code": "General.widgetCancelForm(args.owner.widget);"
                        }
                    ]
                },
                {
                    "id": "",
                    "name": "BACK_LIST",
                    "label": "Voltar",
                    "isVisible": true,
                    "showAsAction": "back_list",
                    "events": [
                        {
                            "id": "",
                            "name": "ActionEvent",
                            "code": "General.widgetGoBackToParent(args.owner.widget);"
                        }
                    ]
                },
                {
                    "id": "",
                    "name": "BACK_VIEW",
                    "label": "Voltar",
                    "isVisible": true,
                    "showAsAction": "back_view",
                    "events": [
                        {
                            "id": "",
                            "name": "ActionEvent",
                            "code": "General.widgetGoBackToList(args.owner.widget);"
                        }
                    ]
                }
            ],
            "fields": [
                {
                    "id": "",
                    "name": "NRPARCNEGOCIO",
                    "label": "",
                    "template": "field/text-edit.html",
                    "isVisible": false,
                    "showOnForm": false,
                    "showOnList": false,
                    "class": "12"
                },
                {
                    "id": "",
                    "name": "DSFILACONTATO",
                    "label": "Assunto",
                    "template": "field/text-edit.html",
                    "isVisible": true,
                    "showOnList": true,
                    "showOnView": true,
                    "showOnForm": true,
                    "maxlength": 2000,
                    "class": "12",
                    "validations": {
                        "required": {}
                    },
                    "events": [],
                    "descriptionOrder": 1
                },
                {
                    "id": "",
                    "name": "DSCLASSIFICATAREFA",
                    "label": "Classificação",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnList": false,
                    "showOnView": true,
                    "showOnForm": true,
                    "class": "6",
                    "itemsPerPage": 30,
                    "validations": {},
                    "valueField": "",
                    "descriptionField": "DSCLASSIFICATAREFA",
                    "dataSource": {
                        "name": "product#/crm_classificatarefa",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "fields": [
                        {
                            "id": "",
                            "name": "DSCLASSIFICATAREFA",
                            "label": "Classificação",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        }
                    ],
                    "dataSourceFilter": [],
                    "outData": {
                        "NRSEQCLASSIFICATAREFA": "NRSEQCLASSIFICATAREFA",
                        "DSCLASSIFICATAREFA": "DSCLASSIFICATAREFA"
                    },
                    "events": []
                },
                {
                    "id": "",
                    "name": "DTPLANFILACONTA",
                    "label": "Data/Hora de Contato",
                    "template": "field/datetime.html",
                    "datetime-dateFormat": "dd/mm/yy",
                    "datetime-timeFormat": "HH:ii",
                    "datetime-preset": "datetime",
                    "isVisible": true,
                    "showOnList": true,
                    "showOnView": true,
                    "showOnForm": true,
                    "class": "6",
                    "validations": {
                        "required": {}
                    },
                    "events": []
                },
                {
                    "id": "",
                    "name": "NMOPERADOR",
                    "label": "Operador Responsável",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnList": true,
                    "showOnView": true,
                    "showOnForm": true,
                    "class": "12",
                    "itemsPerPage": 30,
                    "valueField": "CDOPERADOR",
                    "descriptionField": "NMOPERADOR",
                    "validations": {
                        "required": {}
                    },
                    "dataSource": {
                        "name": "product#/crud/operador_crm_operrevenda",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "dataSourceFilter": [
                        {
                            "name": "IDTPOPERADOR",
                            "operator": "=",
                            "value": "@Util.isEmptyOrBlank(templateManager.LOGGEDOPERATOR.IDTPOPERADOR) ? 'E' : templateManager.LOGGEDOPERATOR.IDTPOPERADOR@"
                        }
                    ],
                    "fields": [
                        {
                            "id": "",
                            "name": "NMOPERADOR",
                            "label": "Nome",
                            "isVisible": true,
                            "showOnList": true
                        }
                    ],
                    "outData": {
                        "NMOPERADOR": "NMOPERADOR",
                        "CDOPERADOR": "CDOPERREAL"
                    },
                    "events": []
                },
                {
                    "id": "",
                    "name": "DTREALFILACONTA",
                    "label": "Data de Conclusão",
                    "template": "field/calendar.html",
                    "isVisible": true,
                    "showOnList": true,
                    "showOnView": true,
                    "showOnForm": true,
                    "readOnly": true,
                    "dateFormat": "DD/MM/YYYY",
                    "class": "6",
                    "events": []
                },
                {
                    "id": "",
                    "name": "NRPRIORFILACONT",
                    "label": "Prioridade",
                    "template": "field/select-native.html",
                    "hideEmptyValue": true,
                    "isVisible": true,
                    "showOnList": false,
                    "showOnView": true,
                    "showOnForm": true,
                    "class": "6",
                    "descriptionField": "NMPRIORFILACONT",
                    "valueField": "NRPRIORFILACONT",
                    "defaultValue": 2,
                    "validations": {
                        "required": {}
                    },
                    "dataSource": {
                        "data": [
                            {
                                "NRPRIORFILACONT": 2,
                                "NMPRIORFILACONT": "Normal"
                            },
                            {
                                "NRPRIORFILACONT": 1,
                                "NMPRIORFILACONT": "Prioridade"
                            }
                        ]
                    },
                    "events": []
                },
                {
                    "id": "",
                    "name": "NMINTERLOCUTOR",
                    "label": "Interlocutor",
                    "template": "field/select.html",
                    "showSelectAs": "grid",
                    "isVisible": true,
                    "showOnForm": true,
                    "class": "12",
                    "valueField": "NRSEQINTERLOCUTOR",
                    "descriptionField": "NMINTERLOCUTOR",
                    "dataSource": {
                        "name": "product#/crud/crm_interlocutor",
                        "rest": true,
                        "lazyLoad": true
                    },
                    "dataSourceFilter": [
                        {
                            "name": "NRPARCNEGOCIO",
                            "operator": "=",
                            "value": "@templateManager.container.getWidget('gridProspect').currentRow.NRPARCNEGOCIO@"
                        }
                    ],
                    "outData": {
                        "NMINTERLOCUTOR": "NMINTERLOCUTOR",
                        "NRSEQINTERLOCUTOR": "NRSEQINTERLOCUTOR",
                        "NRTELEFONE1": "DSTELEFONETAREFA",
                        "EMAILINTERLOC": "DSEMAILTAREFA"
                    },
                    "fields": [
                        {
                            "id": "",
                            "name": "NMINTERLOCUTOR",
                            "label": "Nome",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        },
                        {
                            "id": "",
                            "name": "NMCARGOINTERLOC",
                            "label": "Cargo",
                            "isVisible": true,
                            "showOnList": true,
                            "template": "field/text-edit.html"
                        }
                    ],
                    "events": [
                        {
                            "id": "",
                            "name": "FieldOnClick",
                            "code": "args.owner.field.reload();"
                        }
                    ]
                },
                {
                    "id": "",
                    "name": "DSTELEFONETAREFA",
                    "label": "Telefone",
                    "template": "field/phone.html",
                    "isVisible": true,
                    "showOnList": false,
                    "showOnView": true,
                    "showOnForm": true,
                    "class": "6",
                    "maxlength": 15,
                    "events": []
                },
                {
                    "id": "",
                    "name": "DSEMAILTAREFA",
                    "label": "E-mail",
                    "template": "field/text-edit.html",
                    "isVisible": true,
                    "showOnList": false,
                    "showOnView": true,
                    "showOnForm": true,
                    "class": "6",
                    "validations": {
                        "mail": true
                    },
                    "events": []
                },
                {
                    "id": "",
                    "name": "DSDETEFILACONTA",
                    "label": "Descrição",
                    "template": "field/textarea.html",
                    "isVisible": true,
                    "showOnList": false,
                    "showOnView": true,
                    "showOnForm": true,
                    "maxlength": 4000,
                    "class": "12",
                    "events": []
                }
            ],
            "widgets": []
        };
        
        revendaProspectTarefa = metaDataFactory.widgetFactory(revendaProspectTarefa);
        CRM_Utilities.factoryWidgetActions(revendaProspectTarefa);
        
        return revendaProspectTarefa;
        
    };
    
    
    this.openWindowProspect = function(widget){
           

        var windowToOpen     = 'ger45000_prospect';
        var widgetToFilter   = 'gridProspect';
     
       
        ScreenService.confirmMessage('Deseja ir para a tela de Prospect?', 'CONFIRMATION',
        function(success){
            ScreenService.openWindow('product#'+windowToOpen).
              then(function(){
                    widgetToFilter = templateManager.container.getWidget(widgetToFilter);
                    var filter = [{
                        name : "NRPARCNEGOCIO",
                        operator : "=",
                        static : true,
                        value : widget.currentRow.NRPARCNEGOCIO
                    }]; 
                    
                    widgetToFilter.dataSourceFilter = filter;
                    widgetToFilter.reload().
                      then(function(){
                        ScreenService.closePopup(true);
                        widgetToFilter.reload();
                    });
              });
        });
    };
    
    
    
}

Configuration(function(ContextRegister) {
    ContextRegister.register('crm00050000_Associacoes_Revenda_Controller', crm00050000_Associacoes_Revenda_Controller);
});